A Package for converting between a lot of units

**Installing**

To install just run the following command:

```
pip install master-converter
```

**Code Examples**

```
from conversions import Length

feet = Length().Inches(10).Inches_Feet()
print(feet)
```
